@@ -157,6 +157,11 @@ class SupplyCurveAggregationConfig(AnalysisConfig):
         """Get the SC resolution"""
         return self.get('resolution', self._default_resolution)
 
+    @property
+    def excl_area(self):
+        """Get the exclusion pixel area in km2"""
+        return self.get('excl_area', None)
+
     @property
     def power_density(self):
         """Get the power density (MW/km2) or string to variable power
